==> gcl-1.0.tgz: gcl-1.0/lsp/describe.h <==

static L2();
static L3();
static L4();
static L16();
static L17();
static L18();
static L19();
static L22();
static object LI1();
#define VMB1 register object *base=vs_top;
#define VMS1  register object *sup=vs_top+2;vs_top=sup;
#define VMV1 vs_reserve(2);
#define VMR1(VMT1) vs_top=base ; return(VMT1);
#define VC2 object  V7;
#define VC4 object  V15;
#define VC5 object  V17;
static object LI5();
#define VMB6 register object *base=vs_top; object  V18;
#define VMS6  register object *sup=vs_top+3;vs_top=sup;
#define VMV6 vs_reserve(3);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI6();
#define VMB7 register object *base=vs_top; object  V21 ,V20;
#define VMS7  register object *sup=vs_top+3;vs_top=sup;
#define VMV7 vs_reserve(3);
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI7();
#define VMB8 register object *base=vs_top; object  V37 ,V36 ,V35 ,V34 ,V26;
#define VMS8  register object *sup=vs_top+6;vs_top=sup;
#define VMV8 vs_reserve(6);
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI8();
#define VMB9 register object *base=vs_top;
#define VMS9  register object *sup=vs_top+3;vs_top=sup;
#define VMV9 vs_reserve(3);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI9();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+3;vs_top=sup;
#define VMV10 vs_reserve(3);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI10();
#define VMB11 register object *base=vs_top; object  V56;
#define VMS11  register object *sup=vs_top+3;vs_top=sup;
#define VMV11 vs_reserve(3);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI11();
#define VMB12 register object *base=vs_top; object  V83;
#define VMS12  register object *sup=vs_top+4;vs_top=sup;
#define VMV12 vs_reserve(4);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI12();
#define VMB13 register object *base=vs_top;
#define VMS13  register object *sup=vs_top+5;vs_top=sup;
#define VMV13 vs_reserve(5);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI13();
#define VMB14 register object *base=vs_top;
#define VMS14  register object *sup=vs_top+5;vs_top=sup;
#define VMV14 vs_reserve(5);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI14();
#define VMB15 register object *base=vs_top;
#define VMS15  register object *sup=vs_top+3;vs_top=sup;
#define VMV15 vs_reserve(3);
#define VMR15(VMT15) vs_top=base ; return(VMT15);
static object LI15();
#define VMB16 register object *base=vs_top;
#define VMS16  register object *sup=vs_top+12;vs_top=sup;
#define VMV16 vs_reserve(12);
#define VMR16(VMT16) vs_top=base ; return(VMT16);
#define VC17 object  V135 ,V134 ,V133 ,V132 ,V131 ,V130 ,V129 ,V128 ,V127;
#define VC18
#define VC19
#define VC20 object  V152 ,V149 ,V148 ,V145 ,V144;
#define VC21 object  V186 ,V185 ,V184; GEN  V183= 0,V183alloc ,V182= 0,V182alloc; object  V170 ,V169 ,V168; GEN  V167= 0,V167alloc ,V166= 0,V166alloc;
static L21();
#define VC22 object  V190 ,V189;
static L20();
#define VC23
#define VM23 7
#define VM22 1
#define VM21 9
#define VM20 9
#define VM19 9
#define VM18 7
#define VM17 7
#define VM16 12
#define VM15 3
#define VM14 5
#define VM13 5
#define VM12 4
#define VM11 3
#define VM10 3
#define VM9 3
#define VM8 6
#define VM7 3
#define VM6 3
#define VM5 6
#define VM4 6
#define VM2 10
#define VM3 0
#define VM1 2
static char * VVi[203]={
#define Cdata VV[202]
(char *)(LI1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(L16),
(char *)(L17),
(char *)(L18),
(char *)(L19),
(char *)(L22)
};
#define VV ((object *)VVi)
static object  LnkTLI201() ;
static object  (*LnkLI201)() = LnkTLI201;
static  LnkT200() ;
static  (*Lnk200)() = LnkT200;
static  LnkT199() ;
static  (*Lnk199)() = LnkT199;
static  LnkT198() ;
static  (*Lnk198)() = LnkT198;
static  LnkT197() ;
static  (*Lnk197)() = LnkT197;
static object  LnkTLI196() ;
static object  (*LnkLI196)() = LnkTLI196;
static object  LnkTLI195() ;
static object  (*LnkLI195)() = LnkTLI195;
static object  LnkTLI194() ;
static object  (*LnkLI194)() = LnkTLI194;
static object  LnkTLI193() ;
static object  (*LnkLI193)() = LnkTLI193;
static object  LnkTLI192() ;
static object  (*LnkLI192)() = LnkTLI192;
static object  LnkTLI191() ;
static object  (*LnkLI191)() = LnkTLI191;
static object  LnkTLI190() ;
static object  (*LnkLI190)() = LnkTLI190;
static object  LnkTLI189() ;
static object  (*LnkLI189)() = LnkTLI189;
static object  LnkTLI188() ;
static object  (*LnkLI188)() = LnkTLI188;
static object  LnkTLI187() ;
static object  (*LnkLI187)() = LnkTLI187;
static  LnkT186() ;
static  (*Lnk186)() = LnkT186;
static  LnkT185() ;
static  (*Lnk185)() = LnkT185;
static object  LnkTLI184() ;
static object  (*LnkLI184)() = LnkTLI184;
static  LnkT183() ;
static  (*Lnk183)() = LnkT183;
static  LnkT169() ;
static  (*Lnk169)() = LnkT169;
static  LnkT168() ;
static  (*Lnk168)() = LnkT168;
static  LnkT32() ;
static  (*Lnk32)() = LnkT32;
static  LnkT167() ;
static  (*Lnk167)() = LnkT167;
static object  LnkTLI166() ;
static object  (*LnkLI166)() = LnkTLI166;
static object  LnkTLI165() ;
static object  (*LnkLI165)() = LnkTLI165;
static  LnkT164() ;
static  (*Lnk164)() = LnkT164;
static object  LnkTLI163() ;
static object  (*LnkLI163)() = LnkTLI163;

==> gcl-2.0.tgz: gcl-2.0/lsp/describe.h <==

static L2();
static L3();
static L4();
static L16();
static L17();
static L18();
static L19();
static L22();
static object LI1();
#define VMB1 register object *base=vs_top;
#define VMS1  register object *sup=vs_top+2;vs_top=sup;
#define VMV1 vs_reserve(2);
#define VMR1(VMT1) vs_top=base ; return(VMT1);
#define VC2 object  V7;
#define VC4 object  V15;
#define VC5 object  V17;
static object LI5();
#define VMB6 register object *base=vs_top; object  V18;
#define VMS6  register object *sup=vs_top+3;vs_top=sup;
#define VMV6 vs_reserve(3);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI6();
#define VMB7 register object *base=vs_top; object  V21 ,V20;
#define VMS7  register object *sup=vs_top+3;vs_top=sup;
#define VMV7 vs_reserve(3);
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI7();
#define VMB8 register object *base=vs_top; object  V37 ,V36 ,V35 ,V34 ,V26;
#define VMS8  register object *sup=vs_top+6;vs_top=sup;
#define VMV8 vs_reserve(6);
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI8();
#define VMB9 register object *base=vs_top;
#define VMS9  register object *sup=vs_top+3;vs_top=sup;
#define VMV9 vs_reserve(3);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI9();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+3;vs_top=sup;
#define VMV10 vs_reserve(3);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI10();
#define VMB11 register object *base=vs_top; object  V56;
#define VMS11  register object *sup=vs_top+3;vs_top=sup;
#define VMV11 vs_reserve(3);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI11();
#define VMB12 register object *base=vs_top; object  V83;
#define VMS12  register object *sup=vs_top+4;vs_top=sup;
#define VMV12 vs_reserve(4);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI12();
#define VMB13 register object *base=vs_top;
#define VMS13  register object *sup=vs_top+5;vs_top=sup;
#define VMV13 vs_reserve(5);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI13();
#define VMB14 register object *base=vs_top;
#define VMS14  register object *sup=vs_top+5;vs_top=sup;
#define VMV14 vs_reserve(5);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI14();
#define VMB15 register object *base=vs_top;
#define VMS15  register object *sup=vs_top+3;vs_top=sup;
#define VMV15 vs_reserve(3);
#define VMR15(VMT15) vs_top=base ; return(VMT15);
static object LI15();
#define VMB16 register object *base=vs_top;
#define VMS16  register object *sup=vs_top+12;vs_top=sup;
#define VMV16 vs_reserve(12);
#define VMR16(VMT16) vs_top=base ; return(VMT16);
#define VC17 object  V135 ,V134 ,V133 ,V132 ,V131 ,V130 ,V129 ,V128 ,V127;
#define VC18
#define VC19
#define VC20 object  V149 ,V148 ,V145 ,V144;
#define VC21 object  V182 ,V181 ,V180; GEN  V179= 0,V179alloc ,V178= 0,V178alloc; object  V166 ,V165 ,V164; GEN  V163= 0,V163alloc ,V162= 0,V162alloc;
static L21();
#define VC22 object  V186 ,V185;
static L20();
#define VC23
#define VM23 7
#define VM22 1
#define VM21 9
#define VM20 8
#define VM19 9
#define VM18 7
#define VM17 7
#define VM16 12
#define VM15 3
#define VM14 5
#define VM13 5
#define VM12 4
#define VM11 3
#define VM10 3
#define VM9 3
#define VM8 6
#define VM7 3
#define VM6 3
#define VM5 6
#define VM4 6
#define VM2 10
#define VM3 0
#define VM1 2
static char * VVi[196]={
#define Cdata VV[195]
(char *)(LI1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(L16),
(char *)(L17),
(char *)(L18),
(char *)(L19),
(char *)(L22)
};
#define VV ((object *)VVi)
static object  LnkTLI194() ;
static object  (*LnkLI194)() = LnkTLI194;
static  LnkT193() ;
static  (*Lnk193)() = LnkT193;
static  LnkT192() ;
static  (*Lnk192)() = LnkT192;
static object  LnkTLI191() ;
static object  (*LnkLI191)() = LnkTLI191;
static object  LnkTLI190() ;
static object  (*LnkLI190)() = LnkTLI190;
static object  LnkTLI189() ;
static object  (*LnkLI189)() = LnkTLI189;
static object  LnkTLI188() ;
static object  (*LnkLI188)() = LnkTLI188;
static object  LnkTLI187() ;
static object  (*LnkLI187)() = LnkTLI187;
static object  LnkTLI186() ;
static object  (*LnkLI186)() = LnkTLI186;
static object  LnkTLI185() ;
static object  (*LnkLI185)() = LnkTLI185;
static object  LnkTLI184() ;
static object  (*LnkLI184)() = LnkTLI184;
static object  LnkTLI183() ;
static object  (*LnkLI183)() = LnkTLI183;
static object  LnkTLI182() ;
static object  (*LnkLI182)() = LnkTLI182;
static  LnkT181() ;
static  (*Lnk181)() = LnkT181;
static  LnkT180() ;
static  (*Lnk180)() = LnkT180;
static object  LnkTLI179() ;
static object  (*LnkLI179)() = LnkTLI179;
static  LnkT178() ;
static  (*Lnk178)() = LnkT178;
static  LnkT164() ;
static  (*Lnk164)() = LnkT164;
static  LnkT163() ;
static  (*Lnk163)() = LnkT163;
static  LnkT32() ;
static  (*Lnk32)() = LnkT32;
static  LnkT162() ;
static  (*Lnk162)() = LnkT162;
static object  LnkTLI161() ;
static object  (*LnkLI161)() = LnkTLI161;
static object  LnkTLI160() ;
static object  (*LnkLI160)() = LnkTLI160;
static  LnkT159() ;
static  (*Lnk159)() = LnkT159;
static object  LnkTLI158() ;
static object  (*LnkLI158)() = LnkTLI158;
